@@ -1,6 +1,6 @@
 package Courriel::Part::Single;
 BEGIN {
-  $Courriel::Part::Single::VERSION = '0.09';
+  $Courriel::Part::Single::VERSION = '0.10';
 }
 
 use strict;
@@ -48,10 +48,12 @@ has disposition => (
 );
 
 has encoding => (
-    is      => 'ro',
-    isa     => NonEmptyStr,
-    lazy    => 1,
-    default => '8bit',
+    is        => 'rw',
+    writer    => '_set_encoding',
+    isa       => NonEmptyStr,
+    lazy      => 1,
+    default   => '8bit',
+    predicate => '_has_encoding',
 );
 
 sub BUILD {
@@ -71,6 +73,13 @@ sub BUILD {
         =~ s/$Courriel::Helpers::LINE_SEP_RE/$Courriel::Helpers::CRLF/g
         if $self->_has_encoded_content_ref();
 
+    if ( !$self->_has_encoding() ) {
+        my @enc = $self->headers()->get('Content-Transfer-Encoding');
+
+        $self->_set_encoding( $enc[0] )
+            if @enc && $enc[0];
+    }
+
     $self->_sync_headers_with_self();
 
     return;
@@ -194,7 +203,7 @@ Courriel::Part::Single - A part which does not contain other parts, only content
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
